.. broker documentation master file, created by
sphinx-quickstart on Sat Aug 17 09:12:33 2024.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

README
======

.. toctree::
   :maxdepth: 2
   :caption: Content

   README.md

Modules
=======

.. toctree::
   :maxdepth: 2
   :glob:
   :titlesonly:
   :caption: Modules

   *biobroker*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`